@@ -1,16 +1,15 @@
 import json
-import traceback
+
 
 import time
 import requests
 from requests.adapters import HTTPAdapter
 from requests.packages.urllib3.util.retry import Retry
 import logging
-import http.client
-import ssl
 import os
-
+import time
 from PyInquirer import style_from_dict, Token, prompt
+
 LOGLEVEL = os.environ.get("LOGLEVEL", "INFO")
 
 logging.basicConfig(
@@ -66,7 +65,6 @@ def prompt_questions(repo, proceed_with_prompt):
 def get_team(answers_github):
     try:
         target_team_name = answers_github.get("target_team_name")
-        source_org = answers_github.get("source_github_org")
         target_org = answers_github.get("target_github_org")
         team_url = f"https://api.github.com/orgs/{target_org}/teams/{target_team_name}"
         password = answers_github.get("github_password")
@@ -77,8 +75,8 @@ def get_team(answers_github):
         if team_resp.status_code == 200:
             team_id = json.loads(team_resp.content.decode()).get("id")
             team_ids.append(team_id)
-            if "parent" in json.loads(team_resp.content.decode()) and json.loads(team_resp.content.decode())[
-                "parent"] is not None:
+            if "parent" in json.loads(team_resp.content.decode()) \
+                    and json.loads(team_resp.content.decode())["parent"] is not None:
                 parent_id = json.loads(team_resp.content.decode())["parent"]["id"]
                 team_ids.append(parent_id)
         else:
@@ -90,14 +88,11 @@ def get_team(answers_github):
         logging.error("Unable to fetch team id", exc_info=True)
 
 
-
 def search_by_topic(topic, source_org, password, answers_github, user_found):
     results = []
 
     logging.info("Searching by topic...")
 
-    topics = topic.split(",")
-
     topics = topic.split(",")
     list_of_topics = [f"topic:{single_topic}" for single_topic in topics]
 
@@ -172,7 +167,8 @@ def search_by_topic(topic, source_org, password, answers_github, user_found):
 
                 except Exception as ex:
                     logging.info("Failed to transfer due to " + str(ex))
-                    traceback.logging.info_exc()
+
+                    logging.exception(ex, exc_info=True)
 
                     proceed_answers_ok = prompt_questions(repo, proceed_with_prompt)
 
@@ -191,6 +187,7 @@ def search_by_topic(topic, source_org, password, answers_github, user_found):
 
 def rename_repo(repo, org, answers, headers):
     try:
+        time.sleep(1)
         team_prefix = answers.get("prefix")
         logging.info(f"Renaming {repo} to {team_prefix}.{repo}")
         url = f"https://api.github.com/repos/{org}/{repo}"
@@ -204,7 +201,8 @@ def rename_repo(repo, org, answers, headers):
             return True
 
         else:
-            logging.error(f"Renaming {repo} failed due to error {str(rename_response.status_code)} and response content is {rename_response.content.decode()}")
+            logging.error(
+                f"Renaming {repo} failed due to error {str(rename_response.status_code)} and response content is {rename_response.content.decode()}")
             errors.append(repo + "| Renaming failed")
             return False
     except Exception as ex:
@@ -212,13 +210,12 @@ def rename_repo(repo, org, answers, headers):
         logging.info(ex)
 
 
-
 def rename_master_to_main(repo, org, answers, headers):
     try:
         logging.info("Renaming master to main")
         team_prefix = answers.get("prefix")
 
-        branch_url = f"https://api.github.com/repos/{org}/{team_prefix}.{repo}/branches/master/rename"
+        branch_url = f"https://api.github.com/repos/{org}/{repo}/branches/master/rename"
         data = {"new_name": "main"}
 
         rename_response = s.post(url=branch_url, headers=headers,
@@ -227,7 +224,8 @@ def rename_master_to_main(repo, org, answers, headers):
             logging.info("Renamed master to main")
             return True
         else:
-            logging.info(f"Renaming to master failed for repo {repo} due to {str(rename_response.status_code)} and response content is {rename_response.content.decode()}")
+            logging.info(
+                f"Renaming to master failed for repo {repo} due to {str(rename_response.status_code)} and response content is {rename_response.content.decode()}")
             errors.append(repo + "| Renaming master failed")
             return False
     except Exception as ex:
@@ -253,7 +251,8 @@ def make_repo_internal(repo, answers, headers):
         if response.status_code == 200:
             logging.info(f"Made {repo} internal after transfer")
         else:
-            logging.info(f"Unable to change privacy of repo {repo} to internal due to error {str(response.status_code)} and response is {response.content.decode()}")
+            logging.info(
+                f"Unable to change privacy of repo {repo} to internal due to error {str(response.status_code)} and response is {response.content.decode()}")
     except Exception as ex:
         logging.exception(f"Unable to change privacy of repo {repo} to internal")
         logging.error(ex)
@@ -310,7 +309,7 @@ def transfer_repo_to_targetorg(repo, answers, headers):
         team_ids = get_team(answers)
 
         logging.info(f"Transferring repo {repo} to {target_org}")
-        url = f"https://api.github.com/repos/{source_org}/{team_prefix}.{repo}/transfer"
+        url = f"https://api.github.com/repos/{source_org}/{repo}/transfer"
 
         data = {"new_owner": target_org, "team_ids": team_ids}
         time.sleep(0.2)
@@ -320,7 +319,8 @@ def transfer_repo_to_targetorg(repo, answers, headers):
             return True
         else:
             errors.append(repo + "| Failed to transfer")
-            logging.info("Transfer failed due to error "+str(response.status_code) + f"response is {response.content.decode()}")
+            logging.info("Transfer failed due to error " + str(
+                response.status_code) + f"response is {response.content.decode()}")
             logging.info(response.content.decode())
             return False
     except Exception as ex:
@@ -368,7 +368,8 @@ def make_team_admin_writers(repo, answers, headers):
                 logging.info(f"Changed {slug} to be a {access_level}")
             else:
                 logging.info(response.content.decode())
-                logging.info(f"Team access failed with error code " + str(response.status_code) + " url is " + team_access_url)
+                logging.info(
+                    f"Team access failed with error code " + str(response.status_code) + " url is " + team_access_url)
             time.sleep(0.5)
     except Exception as ex:
         logging.exception("Updating team access failed due to error")
@@ -403,7 +404,8 @@ def remove_user_as_admin(repo, answers, headers, user):
         if response.status_code == 201 or response.status_code == 204:
             logging.info(f"User {user} removed as admin to the repo {repo}")
         else:
-            logging.info(f"unable to remove {user} as admin to the repo {repo} due to error {response.content.decode()}")
+            logging.info(
+                f"unable to remove {user} as admin to the repo {repo} due to error {response.content.decode()}")
     except Exception as ex:
         logging.exception(f"unable to remove {user} as admin to the repo {repo} due to error {type(ex)} ")
         logging.error(ex)
