@@ -5,6 +5,20 @@ import jenkins
 import json
 from PyInquirer import style_from_dict, Token, prompt
 import re
+import os
+import logging
+import xmltodict
+
+LOGLEVEL = os.environ.get("LOGLEVEL", "INFO")
+
+logging.basicConfig(
+    level=LOGLEVEL,
+    format="%(asctime)s [%(levelname)s] %(message)s",
+    handlers=[
+        logging.FileHandler("jenkins.log"),
+        logging.StreamHandler()
+    ]
+)
 
 style = style_from_dict({
     Token.QuestionMark: '#E91E63 bold',
@@ -56,8 +70,8 @@ def get_jobs(jenkins_answers):
         is_prompt_user = True
         with open(jenkins_answers.get("path_to_data"), "r") as jenkinsFile:
             for line in jenkinsFile.readlines():
-                print(f"Reconfiguring {line}")
-                line = line.replace("\n","")
+                logging.info(f"Reconfiguring {line}")
+                line = line.replace("\n", "")
                 if line.endswith("/"):
                     append_api = "api/json?pretty=true"
                     json_api = f"{line}{append_api}"
@@ -72,7 +86,10 @@ def get_jobs(jenkins_answers):
 
                     config = server.get_job_config(job_name)
 
-                    replace_config(job_name, config, server, jenkins_answers)
+                    if "BitbucketSCMSource" in config:
+                        reconfig_bitbucket(jenkins_answers, job_name, config, server)
+                    else:
+                        replace_config(job_name, config, server, jenkins_answers)
 
                     if is_prompt_user:
                         is_okay_to_proceed = [
@@ -102,36 +119,70 @@ def replace_config(job_name, config, server, jenkins_answers):
     old_org = jenkins_answers.get("old_org")
     new_org = jenkins_answers.get("new_org")
 
-    api_uri = "<apiUri>https://github.nike.com/api/v3<apiUri>"
-    config = config.replace(old_org + "/", f"{new_org}/{team_prefix}.").replace(api_uri,
-                                                                                "<apiUri>https://api.github.com<apiUri>")
-    config = config.replace("github.nike.com", "github.com")
-    for org in old_org.split(","):
-        config = config.replace(org, new_org)
-    if credentials_id.strip() != "":
-        config = re.sub("<credentialsId>.*</credentialsId>", f"<credentialsId>{credentials_id}</credentialsId>",
-                        config)
-    # job_name = job.get("name")
+    if "BitbucketSCMSource" in config:
+        logging.info(" Got a bitbucket job to reconfig")
+        reconfig_bitbucket(jenkins_answers=jenkins_answers, job_name=job_name, config=config, server=server)
+    else:
+        api_uri = "<apiUri>https://github.nike.com/api/v3<apiUri>"
+        config = config.replace(old_org + "/", f"{new_org}/{team_prefix}.").replace(api_uri,
+                                                                                    "<apiUri>https://api.github.com<apiUri>")
+        config = config.replace("github.nike.com", "github.com")
+        for org in old_org.split(","):
+            config = config.replace(org, new_org)
+        if credentials_id.strip() != "":
+            config = re.sub("<credentialsId>.*</credentialsId>", f"<credentialsId>{credentials_id}</credentialsId>",
+                            config)
 
-    # change_name = [
-    #
-    #     {
-    #         'type': 'confirm',
-    #         'name': 'change_name',
-    #         'message': f"Change the bmx job name {job_name} to team_prefix.<oldname>?"
-    #     }
-    # ]
-    #
-    # change_name_answers = prompt(change_name, style=style)
-    #
-    # if change_name_answers.get("change_name"):
-    #     job_match = re.findall(r'<displayName>.*</displayName>', config)
-    #     if len(job_match)>0:
-    #         job_name = job_match[0].replace("displayName", "").replace("<>", "").replace("</>", "")
-    #
-    #         new_job_name = f"{team_prefix}.{job_name}"
-    #         config = re.sub("<displayName>.*</displayName>", f"<displayName>{new_job_name}</displayName>", config)
-    #     else:
-    #         print("unable to change name")
-    server.reconfig_job(job_name, config_xml=config)
-    print(f"completed configuring {job_name}")
+        server.reconfig_job(job_name, config_xml=config)
+        logging.info(f"completed configuring {job_name}")
+
+
+def reconfig_bitbucket(jenkins_answers, job_name, config, server):
+    credentials_id = jenkins_answers.get("new_credentials_id")
+    team_prefix = jenkins_answers.get("team_prefix")
+
+    config = server.get_job_config(job_name)
+
+    config_dict = xmltodict.parse(config)
+    if "org.jenkinsci.plugins.workflow.multibranch.WorkflowMultiBranchProject" in config_dict:
+        repo_name = config_dict["org.jenkinsci.plugins.workflow.multibranch.WorkflowMultiBranchProject"]["sources"]["data"][
+            "jenkins.branch.BranchSource"]["source"]["repository"]
+        id_class = config_dict["org.jenkinsci.plugins.workflow.multibranch.WorkflowMultiBranchProject"]["sources"]["data"][
+            "jenkins.branch.BranchSource"]["source"]["id"]
+    elif "org.jenkinsci.plugins.workflow.job.WorkflowJob" in config_dict:
+        repo_name = config_dict["org.jenkinsci.plugins.workflow.job.WorkflowJob"]["sources"]["data"][
+            "jenkins.branch.BranchSource"]["source"]["repository"]
+        id_class = config_dict["org.jenkinsci.plugins.workflow.job.WorkflowJob"]["sources"]["data"][
+            "jenkins.branch.BranchSource"]["source"]["id"]
+
+    source = {
+        "@plugin": "github-branch-source@2.8.2",
+        "@class": "org.jenkinsci.plugins.github_branch_source.GitHubSCMSource",
+        "id": id_class,
+        "apiUri": "https://github.nike.com/api/v3",
+        "credentialsId": f"{credentials_id}",
+        "repoOwner": "nike-internal",
+        "repository": f"{repo_name}",
+        "repositoryUrl": f"https://github.com/nike-internal/{team_prefix}.{repo_name}.git",
+        "traits": {
+            "org.jenkinsci.plugins.github__branch__source.BranchDiscoveryTrait": {
+                "strategyId": "1"
+            },
+            "org.jenkinsci.plugins.github__branch__source.OriginPullRequestDiscoveryTrait": {
+                "strategyId": "1"
+            },
+            "org.jenkinsci.plugins.github__branch__source.ForkPullRequestDiscoveryTrait": {
+                "strategyId": "1",
+                "trust": {
+                    "@class": "com.cloudbees.jenkins.plugins.bitbucket.ForkPullRequestDiscoveryTrait$TrustTeamForks"
+                }
+            }
+        }
+    }
+
+    config_dict["org.jenkinsci.plugins.workflow.multibranch.WorkflowMultiBranchProject"]["sources"]["data"][
+        "jenkins.branch.BranchSource"]["source"] = source
+
+    reconfig_xml = (xmltodict.unparse(config_dict, pretty=True))
+    reconfig_xml.replace(">master<", ">main<")
+    resp = server.reconfig_job(job_name, reconfig_xml)
